@@ -434,28 +434,34 @@ class cExportItem(gmBusinessDBObject.cBusinessDBObject):
 		if not self._payload[self._idx['filename']].startswith('DIR::'):
 			return False
 		if len(self._payload[self._idx['filename']].split('::', 2)) != 3:
+			_log.exception('DIRENTRY [%s]: malformed', self._payload[self._idx['filename']])
 			return False
 		return True
 
 	is_DIRENTRY = property(_is_DIRENTRY)
 
 	#--------------------------------------------------------
-	def _is_valid_DIRENTRY(self):
-		"""Check whether this item is a _valid_ DIRENTRY."""
+	def _is_local_DIRENTRY(self):
+		"""Check whether this item is a _local_ DIRENTRY."""
 		if not self.is_DIRENTRY:
 			return False
-		# malformed ?
-		try:
-			tag, node, local_fs_path = self._payload[self._idx['filename']].split('::', 2)
-		except ValueError:
-			# should not happen because structure already checked in .is_DIRENTRY,
-			# better safe than sorry
-			_log.exception('DIRENTRY [%s]: malformed', self._payload[self._idx['filename']])
-			return False
-		# this machine ?
-		if node != platform.node():
-			_log.warning('DIRENTRY [%s]: not on this machine (%s)', self._payload[self._idx['filename']], platform.node())
+
+		tag, node, local_fs_path = self._payload[self._idx['filename']].split('::', 2)
+		if node == platform.node():
+			return True
+
+		_log.warning('DIRENTRY [%s]: not on this machine (%s)', self._payload[self._idx['filename']], platform.node())
+		return False
+
+	is_local_DIRENTRY = property(_is_local_DIRENTRY)
+
+	#--------------------------------------------------------
+	def _is_valid_DIRENTRY(self):
+		"""Check whether this item is a _valid_ DIRENTRY."""
+		if not self.is_local_DIRENTRY:
 			return False
+
+		tag, node, local_fs_path = self._payload[self._idx['filename']].split('::', 2)
 		# valid path ?
 		if not os.path.isdir(local_fs_path):
 			_log.warning('DIRENTRY [%s]: directory not found (old DIRENTRY ?)', self._payload[self._idx['filename']])
@@ -464,6 +470,40 @@ class cExportItem(gmBusinessDBObject.cBusinessDBObject):
 
 	is_valid_DIRENTRY = property(_is_valid_DIRENTRY)
 
+	#--------------------------------------------------------
+	def _get_DIRENTRY_node(self):
+		if not self.is_DIRENTRY:
+			return None
+
+		try:
+			tag, node, local_fs_path = self._payload[self._idx['filename']].split('::', 2)
+		except ValueError:
+			# should not happen because structure already checked in .is_DIRENTRY,
+			# better safe than sorry
+			_log.exception('DIRENTRY [%s]: malformed', self._payload[self._idx['filename']])
+			return None
+
+		return node
+
+	DIRENTRY_node = property(_get_DIRENTRY_node)
+
+	#--------------------------------------------------------
+	def _get_DIRENTRY_path(self):
+		if not self.is_DIRENTRY:
+			return None
+
+		try:
+			tag, node, local_fs_path = self._payload[self._idx['filename']].split('::', 2)
+		except ValueError:
+			# should not happen because structure already checked in .is_DIRENTRY,
+			# better safe than sorry
+			_log.exception('DIRENTRY [%s]: malformed', self._payload[self._idx['filename']])
+			return None
+
+		return local_fs_path
+
+	DIRENTRY_path = property(_get_DIRENTRY_path)
+
 	#--------------------------------------------------------
 	def _is_DICOM_directory(self):
 		"""Check whether this item points to a DICOMDIR."""
@@ -887,11 +927,7 @@ class cExportArea(object):
 	#--------------------------------------------------------
 	def remove_item(self, item):
 		if item.is_valid_DIRENTRY:
-			tag, node, local_fs_path = item['filename'].split('::', 2)
-			gmTools.remove_file(os.path.join(local_fs_path, DIRENTRY_README_NAME))
-		elif item.is_DIRENTRY:
-			return False
-
+			gmTools.remove_file(os.path.join(item.DIRENTRY_path, DIRENTRY_README_NAME))
 		return delete_export_item(pk_export_item = item['pk_export_item'])
 
 	#--------------------------------------------------------
@@ -944,7 +980,8 @@ class cExportArea(object):
 		pat = cPatient(aPK_obj = self.__pk_identity)
 		target_base_dir = base_dir
 		if target_base_dir is None:
-			target_base_dir = gmTools.mk_sandbox_dir(prefix = '%s-' % pat.subdir_name)
+			target_sandbox_dir = gmTools.mk_sandbox_dir()
+			target_base_dir = os.path.join(target_sandbox_dir, pat.subdir_name)
 		gmTools.mkdir(target_base_dir)
 		_log.debug('patient media base dir: %s', target_base_dir)
 		if not gmTools.dir_is_empty(target_base_dir):
@@ -956,7 +993,7 @@ class cExportArea(object):
 
 		html_data = {}
 
-		# 1) assemble everything in a sandbox
+		# 1) assemble everything into a sandbox
 		# - setup sandbox
 		sandbox_dir = gmTools.mk_sandbox_dir()
 		_log.debug('sandbox dir: %s', sandbox_dir)
@@ -974,7 +1011,7 @@ class cExportArea(object):
 		pat.export_as_gdt(filename = os.path.join(sandbox_dir, 'patient.gdt'))
 		pat.export_as_xml_linuxmednews(filename = os.path.join(sandbox_dir, 'patient.xml'))
 		pat.export_as_vcard(filename = os.path.join(sandbox_dir, 'patient.vcf'))
-		pat.export_as_mecard(filename = os.path.join(sandbox_dir, u'patient.mcf'))
+		pat.export_as_mecard(filename = os.path.join(sandbox_dir, 'patient.mcf'))
 		# - create CD.INF
 		self._create_cd_inf(pat, sandbox_dir)
 		# - export items
@@ -1092,6 +1129,7 @@ class cExportArea(object):
 		if export_dir is None:
 			_log.debug('cannot export items')
 			return None
+
 		if passphrase is None:
 			zip_file = gmCrypto.create_zip_archive_from_dir (
 				export_dir,
@@ -1110,6 +1148,7 @@ class cExportArea(object):
 		if zip_file is None:
 			_log.debug('cannot create zip archive')
 			return None
+
 		return zip_file
 
 	#--------------------------------------------------------
