@@ -254,6 +254,7 @@ class cFormTemplate(gmBusinessDBObject.cBusinessDBObject):
 	def instantiate(self, use_sandbox=False):
 		fname = self.save_to_file(use_sandbox = use_sandbox)
 		if not fname:
+			_log.debug('cannot save form data to file')
 			return None
 
 		engine = form_engines[self._payload[self._idx['engine']]]
@@ -525,6 +526,7 @@ class gmOOoConnector(gmBorg.cBorg):
 
 		self.remote_context_uri = "uno:pipe,name=%s;urp;StarOffice.ComponentContext" % pipe_name
 		_log.debug('remote context URI: %s', self.remote_context_uri)
+
 	#--------------------------------------------------------
 	def __startup_ooo(self):
 		_log.info('trying to start OOo server')
@@ -532,7 +534,8 @@ class gmOOoConnector(gmBorg.cBorg):
 		os.system(self.ooo_start_cmd)
 		self.__get_startup_settle_time()
 		_log.debug('waiting %s seconds for OOo to start up', self.ooo_startup_settle_time)
-		time.sleep(self.ooo_startup_settle_time)
+		time.sleep(int(self.ooo_startup_settle_time))
+
 	#--------------------------------------------------------
 	# properties
 	#--------------------------------------------------------
@@ -2243,6 +2246,8 @@ if __name__ == '__main__':
 	if sys.argv[1] != 'test':
 		sys.exit()
 
+	gmLog2.print_logfile_name()
+
 	gmDateTime.init()
 
 	#--------------------------------------------------------
@@ -2393,13 +2398,14 @@ if __name__ == '__main__':
 		pat = gmPersonSearch.ask_for_patient()
 		if pat is None:
 			return
+
+		print(pat)
 		gmPerson.set_active_patient(patient = pat)
-
 		gmStaff.gmCurrentProvider(provider = gmStaff.cStaff())
-
 		path = os.path.abspath(sys.argv[2])
+		print(path)
 		form = cTextForm(template_file = path)
-
+		print(form)
 		from Gnumed.wxpython import gmMacro
 		ph = gmMacro.gmPlaceholderHandler()
 		ph.debug = True
@@ -2407,6 +2413,7 @@ if __name__ == '__main__':
 		print(form.re_editable_filenames)
 		form.edit()
 		form.generate_output()
+
 	#--------------------------------------------------------
 	#--------------------------------------------------------
 	#--------------------------------------------------------
@@ -2428,9 +2435,9 @@ if __name__ == '__main__':
 	gmPG2.request_login_params(setup_pool = True)
 	if not gmPraxis.activate_first_praxis_branch():
 		print('no praxis')
-	test_latex_form()
+	#test_latex_form()
 	#test_pdf_form()
 	#test_abiword_form()
-	#test_text_form()
+	test_text_form()
 
 #============================================================
