@@ -1,4 +1,4 @@
-# -*- encoding: utf-8 -*-
+# -*- coding: utf-8 -*-
 """GNUmed German xDT mapping data.
 
 This maps xDT fields in various ways.
@@ -7,12 +7,11 @@ This maps xDT fields in various ways.
 __author__ = "S.Hilbert, K.Hilbert"
 __license__ = "GPL v2 or later"
 
-try:
-	_('dummy-no-need-to-translate-but-make-epydoc-happy')
-except NameError:
+#==============================================================
+if __name__ == '__main__':
 	_ = lambda x:x
 
-#==============================================================
+
 # FIXME: xBDT incorporated only up to (excluding) Satzart 0101 (Do 09 Aug 2007 11:10:16 CEST)
 xdt_id_map = {
 
@@ -159,11 +158,11 @@ xdt_id_map = {
 	'3210': 'Geschlecht des Hauptversicherten',	# nur bei header 0191
 
 	# scheinbar alter BDT ? (Quelle: mediSYS GmbH)
-	'3301': u'Name des Patienten',
-	'3302': u'Vorname des Patienten',
-	'3303': u'Geburtsdatum des Patienten (TTMMJJ)',
-	'3306': u'PLZ/Wohnort des Patienten',
-	'3307': u'Straße/Hausnummer des Patienten',
+	'3301': 'Name des Patienten',
+	'3302': 'Vorname des Patienten',
+	'3303': 'Geburtsdatum des Patienten (TTMMJJ)',
+	'3306': 'PLZ/Wohnort des Patienten',
+	'3307': 'Straße/Hausnummer des Patienten',
 	'3308': '?? Status Patient',
 
 	'3600': 'Patientennummer (alter BDT ?, beobachtet bei Medistar)',
@@ -173,7 +172,7 @@ xdt_id_map = {
 	'3610': 'Datum Patient seit',							# nur bei header 6100
 	'3612': 'Datum Versichertenbeginn bei Kassenwechsel',	# nur bei header 6100
 	'3620': 'Beruf des Patienten',							# nur bei header 6100
-	'3621': u'Geschlecht des Patienten (Hilfsfeld, gestrichen)',
+	'3621': 'Geschlecht des Patienten (Hilfsfeld, gestrichen)',
 	'3622': 'Grösse des Patienten',							# nur bei header 6100
 	'3623': 'Gewicht des Patienten',						# nur bei header 6100
 	'3625': 'Arbeitgeber des Patienten',					# nur bei header 6100
@@ -558,9 +557,9 @@ xdt_packet_type_map = {
 	'6310': "========<< GDT: Untersuchung übermitteln >>========",
 	'6311': "========<< GDT: Untersuchung anzeigen >>========",
 
-	'8202': u'========<< LDT: LG-Bericht >>========',
-	'8220': u'========<< LDT: L-Datenpaket-Header >>========',
-	'8221': u'========<< LDT: L-Datenpaket-Abschluß >>========',
+	'8202': '========<< LDT: LG-Bericht >>========',
+	'8220': '========<< LDT: L-Datenpaket-Header >>========',
+	'8221': '========<< LDT: L-Datenpaket-Abschluß >>========',
 
 	'adt0': "========<< ADT-Datenpaket-Header >>========",
 	'adt9': "========<< ADT-Datenpaket-Abschluss >>========",
@@ -599,6 +598,8 @@ map_gender_xdt2gm = {
 	'W': 'f',
 	'w': 'f',
 	'5': 'f',
+	'd': 'h',
+	'D': 'h',
 	'U': None
 }
 
@@ -607,7 +608,8 @@ map_gender_gm2xdt = {
 	'f': '2',
 	'tm': '1',
 	'tf': '2',
-	'h': '?'
+	'h': '3',		# 'D' unchecked
+	None: '?'		# 'U'
 }
 
 # LDT "gender", 8407
@@ -1138,22 +1140,22 @@ kvdt_Packungsgroesse_map = {
 	'kA': 'keine Angabe'
 }
 # Heilmittel : 0925
-#kvdt_Heilmittel_map = {
-#	'01': 'Massagetherapie',
-#	'02': 'Bewegungstherapie',
-#	'03': 'Krankengymnastik',
-#	'04': 'Elektrotherapie',
-#	'06': 'Thermotherapie(Wärme- und Kältetherapie)',
-#	'08': 'Kohlensäurebäder',
-#	'09': 'Inhalalationtherapie',
-#	'10': 'Traktionsbehandlung',
-#	'20': 'Stimmtherapie',
-#	'25': 'Sprechtherapie',
-#	'30': 'Sprachtherapie',
-#	'35': 'Sprech- und/oder Sprachtherapie bei Kindern und Jugendlichen',
-#	'40': 'Beschäftigungs- und Arbeitstherapie (Ergotherapie)',
-#	'90': 'Sonstiges',
-#}
+kvdt_Heilmittel_map = {
+	'01': 'Massagetherapie',
+	'02': 'Bewegungstherapie',
+	'03': 'Krankengymnastik',
+	'04': 'Elektrotherapie',
+	'06': 'Thermotherapie(Wärme- und Kältetherapie)',
+	'08': 'Kohlensäurebäder',
+	'09': 'Inhalalationtherapie',
+	'10': 'Traktionsbehandlung',
+	'20': 'Stimmtherapie',
+	'25': 'Sprechtherapie',
+	'30': 'Sprachtherapie',
+	'35': 'Sprech- und/oder Sprachtherapie bei Kindern und Jugendlichen',
+	'40': 'Beschäftigungs- und Arbeitstherapie (Ergotherapie)',
+	'90': 'Sonstiges'
+}
 
 # Kennzeichnung gebührenpflichtig, aut idem, noctu
 kvdt_Kennzeichnung_map = {
