@@ -158,7 +158,7 @@ def guess_ext_by_mimetype(mimetype=''):
 	)
 
 	if ext is not None:
-		_log.debug('<%s>: %s (%s)' % (mimetype, ext, candidate))
+		_log.debug('<%s>: %s' % (mimetype, ext))
 		return ext
 
 	_log.error("<%s>: no suitable file extension found in config files" % mimetype)
@@ -189,16 +189,19 @@ def adjust_extension_by_mimetype(filename):
 	mime_suffix = guess_ext_by_mimetype(mimetype)
 	if mime_suffix is None:
 		return filename
+
 	old_name, old_ext = os.path.splitext(filename)
 	if old_ext == '':
 		new_filename = filename + mime_suffix
 	elif old_ext.lower() == mime_suffix.lower():
 		return filename
+
 	new_filename = old_name + mime_suffix
 	_log.debug('[%s] -> [%s]', filename, new_filename)
 	try:
 		os.rename(filename, new_filename)
 		return new_filename
+
 	except OSError:
 		_log.exception('cannot rename, returning original filename')
 	return filename
@@ -228,7 +231,7 @@ def _get_system_startfile_cmd(filename):
 	if _system_startfile_cmd is not None:
 		return True, _system_startfile_cmd % filename
 
-	open_cmd_candidates = open_cmds.keys()
+	open_cmd_candidates = list(open_cmds)
 
 	for candidate in open_cmd_candidates:
 		found, binary = gmShellAPI.detect_external_binary(binary = candidate)
@@ -266,6 +269,7 @@ def convert_file(filename=None, target_mime=None, target_filename=None, target_e
 			tmp, converted_ext = os.path.splitext(target_filename)
 	if converted_ext is None:
 		converted_ext = target_extension		# can still stay None
+	converted_ext = gmTools.coalesce(converted_ext, '').strip().lstrip('.')
 	converted_fname = gmTools.get_unique_filename(suffix = converted_ext)
 	_log.debug('attempting conversion: [%s] -> [<%s>:%s]', filename, target_mime, gmTools.coalesce(target_filename, converted_fname))
 	script_name = 'gm-convert_file'
@@ -281,7 +285,7 @@ def convert_file(filename=None, target_mime=None, target_filename=None, target_e
 		binary,
 		filename,
 		target_mime,
-		converted_ext.lstrip('.'),
+		converted_ext,
 		converted_fname
 	]
 	success, returncode, stdout = gmShellAPI.run_process(cmd_line = cmd_line, verbose = True)
