@@ -89,11 +89,11 @@ class GregorianTimeType(TimeType):
     def format_period(self, time_period):
         """Returns a unicode string describing the time period."""
         def label_with_time(time):
-            return u"%s %s" % (label_without_time(time), time_label(time))
+            return "%s %s" % (label_without_time(time), time_label(time))
 
         def label_without_time(time):
             gregorian_datetime = GregorianDateTime.from_time(time)
-            return u"%s %s %s" % (
+            return "%s %s %s" % (
                 gregorian_datetime.day,
                 abbreviated_name_of_month(gregorian_datetime.month),
                 format_year(gregorian_datetime.year)
@@ -103,16 +103,16 @@ class GregorianTimeType(TimeType):
             return "%02d:%02d" % time.get_time_of_day()[:-1]
         if time_period.is_period():
             if has_nonzero_time(time_period):
-                label = u"%s to %s" % (label_with_time(time_period.start_time),
-                                       label_with_time(time_period.end_time))
+                label = "%s to %s" % (label_with_time(time_period.start_time),
+                                      label_with_time(time_period.end_time))
             else:
-                label = u"%s to %s" % (label_without_time(time_period.start_time),
-                                       label_without_time(time_period.end_time))
+                label = "%s to %s" % (label_without_time(time_period.start_time),
+                                      label_without_time(time_period.end_time))
         else:
             if has_nonzero_time(time_period):
-                label = u"%s" % label_with_time(time_period.start_time)
+                label = "%s" % label_with_time(time_period.start_time)
             else:
-                label = u"%s" % label_without_time(time_period.start_time)
+                label = "%s" % label_without_time(time_period.start_time)
         return label
 
     def format_delta(self, delta):
@@ -176,7 +176,7 @@ class GregorianTimeType(TimeType):
         return (GregorianDelta.from_seconds(60), _("Can't zoom deeper than 1 minute"))
 
     def get_name(self):
-        return u"gregoriantime"
+        return "gregoriantime"
 
     def get_duplicate_functions(self):
         return [
@@ -335,7 +335,7 @@ def _move_page_months(curret_period, navigation_fn, direction):
 
 
 def _months_to_year_and_month(months):
-    years = int(months / 12)
+    years = int(months // 12)
     month = months - years * 12
     if month == 0:
         month = 12
@@ -401,7 +401,7 @@ def fit_millennium_fn(main_frame, current_period, navigation_fn):
     if mean.year > get_millenium_max_year():
         year = get_millenium_max_year()
     else:
-        year = max(get_min_year_containing_jan_1(), int(mean.year / 1000) * 1000)
+        year = max(get_min_year_containing_jan_1(), int(mean.year // 1000) * 1000)
     start = GregorianDateTime.from_ymd(year, 1, 1).to_time()
     end = GregorianDateTime.from_ymd(year + 1000, 1, 1).to_time()
     navigation_fn(lambda tp: tp.update(start, end))
@@ -509,9 +509,9 @@ class StripCentury(Strip):
 
     def _format_century(self, century_number, is_bc):
         if is_bc:
-            return u"{century}s {bc}".format(century=century_number, bc=BC)
+            return "{century}s {bc}".format(century=century_number, bc=BC)
         else:
-            return u"{century}s".format(century=century_number)
+            return "{century}s".format(century=century_number)
 
     def _century_start_year(self, year):
         if year > 99:
@@ -904,22 +904,22 @@ class DurationType(object):
 
 
 YEARS = DurationType(_('years'), _('year'),
-                     lambda ds: ds[0] / 365,
+                     lambda ds: ds[0] // 365,
                      lambda ds: (ds[0] % 365, ds[1]))
 MONTHS = DurationType(_('months'), _('month'),
-                      lambda ds: ds[0] / 30,
+                      lambda ds: ds[0] // 30,
                       lambda ds: (ds[0] % 30, ds[1]))
 WEEKS = DurationType(_('weeks'), _('week'),
-                     lambda ds: ds[0] / 7,
+                     lambda ds: ds[0] // 7,
                      lambda ds: (ds[0] % 7, ds[1]))
 DAYS = DurationType(_('days'), _('day'),
                     lambda ds: ds[0],
                     lambda ds: (0, ds[1]))
 HOURS = DurationType(_('hours'), _('hour'),
-                     lambda ds: ds[0] * 24 + ds[1] / 3600,
+                     lambda ds: ds[0] * 24 + ds[1] // 3600,
                      lambda ds: (0, ds[1] % 3600))
 MINUTES = DurationType(_('minutes'), _('minute'),
-                       lambda ds: ds[0] * 1440 + ds[1] / 60,
+                       lambda ds: ds[0] * 1440 + ds[1] // 60,
                        lambda ds: (0, ds[1] % 60))
 SECONDS = DurationType(_('seconds'), _('second'),
                        lambda ds: ds[0] * 86400 + ds[1],
