@@ -30,6 +30,7 @@ from Gnumed.business import gmStaff
 from Gnumed.business import gmEMRStructItems
 from Gnumed.business import gmClinNarrative
 from Gnumed.business import gmSoapDefs
+from Gnumed.business import gmProviderInbox
 
 from Gnumed.wxpython import gmListWidgets
 from Gnumed.wxpython import gmEMRStructWidgets
@@ -42,8 +43,114 @@ from Gnumed.exporters import gmPatientExporter
 
 
 _log = logging.getLogger('gm.ui')
+
 #============================================================
 # narrative related widgets/functions
+#------------------------------------------------------------
+def edit_narrative(parent=None, narrative=None, single_entry=False):
+	assert isinstance(narrative, gmClinNarrative.cNarrative), '<narrative> must be of type <cNarrative>'
+
+	title = _('Editing progress note')
+	if narrative['modified_by_raw'] == gmStaff.gmCurrentProvider()['db_user']:
+		msg = _('Your original progress note:')
+	else:
+		msg = _('Original progress note by %s [%s]\n(will be notified of changes):') % (
+			narrative['modified_by'],
+			narrative['modified_by_raw']
+		)
+	if parent is None:
+		parent = wx.GetApp().GetTopWindow()
+	dlg = gmGuiHelpers.cMultilineTextEntryDlg (
+		parent,
+		-1,
+		title = title,
+		msg = msg,
+		data = narrative.format(left_margin = ' ', fancy = True),
+		text = narrative['narrative'].strip()
+	)
+	decision = dlg.ShowModal()
+	val = dlg.value.strip()
+	dlg.DestroyLater()
+	if decision != wx.ID_SAVE:
+		return False
+
+	if val == '':
+		return False
+
+	if val == narrative['narrative'].strip():
+		return False
+
+	if narrative['modified_by_raw'] == gmStaff.gmCurrentProvider()['db_user']:
+		narrative['narrative'] = val
+		narrative.save_payload()
+		return True
+
+	q = _(
+		'Original progress note written by someone else:\n'
+		'\n'
+		' %s (%s)\n'
+		'\n'
+		'Upon saving changes that person will be notified.\n'
+		'\n'
+		'Consider saving as a new progress note instead.'
+	) % (
+		narrative['modified_by_raw'],
+		narrative['modified_by']
+	)
+	buttons = [
+		{'label': _('Save changes'), 'default': True},
+		{'label': _('Save new note')},
+		{'label': _('Discard')}
+	]
+	dlg = gmGuiHelpers.c3ButtonQuestionDlg(parent = parent, caption = title, question = q, button_defs = buttons)
+	decision = dlg.ShowModal()
+	dlg.DestroyLater()
+	if decision not in [wx.ID_YES, wx.ID_NO]:
+		return False
+
+	if decision == wx.ID_NO:
+		# create new progress note within the same context as the original one
+		gmClinNarrative.create_narrative_item (
+			narrative = val,
+			soap_cat = narrative['soap_cat'],
+			episode_id = narrative['pk_episode'],
+			encounter_id = narrative['pk_encounter']
+		)
+		return True
+
+	# notify original provider
+	msg = gmProviderInbox.create_inbox_message (
+		staff = narrative.staff_id,
+		message_type = _('Change notification'),
+		message_category = 'administrative',
+		subject = _('A progress note of yours has been edited.'),
+		patient = narrative['pk_patient']
+	)
+	msg['data'] = _(
+		'Original (by [%s]):\n'
+		'%s\n'
+		'\n'
+		'Edited (by [%s]):\n'
+		'%s'
+	) % (
+		narrative['modified_by'],
+		narrative['narrative'].strip(),
+		gmStaff.gmCurrentProvider()['short_alias'],
+		val
+	)
+	msg.save()
+	# notify /me about the staff member notification
+	#gmProviderInbox.create_inbox_message (
+	#	staff = curr_prov['pk_staff'],
+	#	message_type = _('Privacy notice'),
+	#	message_category = 'administrative',
+	#	subject = _('%s: Staff member %s has been notified of your chart access.') % (prov, pat)
+	#)
+	# save narrative change
+	narrative['narrative'] = val
+	narrative.save()
+	return True
+
 #------------------------------------------------------------
 def move_progress_notes_to_another_encounter(parent=None, encounters=None, episodes=None, patient=None, move_all=False):
 
@@ -177,7 +284,7 @@ def manage_progress_notes(parent=None, encounters=None, episodes=None, patient=N
 			-1,
 			title = _('Editing progress note'),
 			msg = _('This is the original progress note:'),
-			data = item.format(left_margin = u' ', fancy = True),
+			data = item.format(left_margin = ' ', fancy = True),
 			text = item['narrative']
 		)
 		decision = dlg.ShowModal()
@@ -186,14 +293,14 @@ def manage_progress_notes(parent=None, encounters=None, episodes=None, patient=N
 			return False
 
 		val = dlg.value
-		dlg.Destroy()
-		if val.strip() == u'':
+		dlg.DestroyLater()
+		if val.strip() == '':
 			return False
 
 		item['narrative'] = val
 		item.save_payload()
-
 		return True
+
 	#--------------------------
 	def refresh(lctrl):
 		notes = emr.get_clin_narrative (
@@ -233,8 +340,8 @@ def search_narrative_across_emrs(parent=None):
 		parent = wx.GetApp().GetTopWindow()
 
 	search_term_dlg = wx.TextEntryDialog (
-		parent = parent,
-		message = _('Enter (regex) term to search for across all EMRs:'),
+		parent,
+		_('Enter (regex) term to search for across all EMRs:'),
 		caption = _('Text search across all EMRs'),
 		style = wx.OK | wx.CANCEL | wx.CENTRE
 	)
@@ -245,7 +352,7 @@ def search_narrative_across_emrs(parent=None):
 
 	wx.BeginBusyCursor()
 	search_term = search_term_dlg.GetValue()
-	search_term_dlg.Destroy()
+	search_term_dlg.DestroyLater()
 	results = gmClinNarrative.search_text_across_emrs(search_term = search_term)
 	wx.EndBusyCursor()
 
@@ -295,20 +402,20 @@ def search_narrative_in_emr(parent=None, patient=None):
 		parent = wx.GetApp().GetTopWindow()
 
 	search_term_dlg = wx.TextEntryDialog (
-		parent = parent,
-		message = _('Enter search term:'),
+		parent,
+		_('Enter search term:'),
 		caption = _('Text search of entire EMR of active patient'),
 		style = wx.OK | wx.CANCEL | wx.CENTRE
 	)
 	result = search_term_dlg.ShowModal()
 
 	if result != wx.ID_OK:
-		search_term_dlg.Destroy()
+		search_term_dlg.DestroyLater()
 		return False
 
 	wx.BeginBusyCursor()
 	val = search_term_dlg.GetValue()
-	search_term_dlg.Destroy()
+	search_term_dlg.DestroyLater()
 	emr = patient.emr
 	rows = emr.search_narrative_simple(val)
 	wx.EndBusyCursor()
@@ -323,24 +430,24 @@ def search_narrative_in_emr(parent=None, patient=None):
 		)
 		return True
 
-	txt = u''
+	txt = ''
 	for row in rows:
-		txt += u'%s: %s\n' % (
+		txt += '%s: %s\n' % (
 			row['soap_cat'],
 			row['narrative']
 		)
 
-		txt += u' %s: %s - %s %s\n' % (
+		txt += ' %s: %s - %s %s\n' % (
 			_('Encounter'),
 			row['encounter_started'].strftime('%x %H:%M'),
 			row['encounter_ended'].strftime('%H:%M'),
 			row['encounter_type']
 		)
-		txt += u' %s: %s\n' % (
+		txt += ' %s: %s\n' % (
 			_('Episode'),
 			row['episode']
 		)
-		txt += u' %s: %s\n\n' % (
+		txt += ' %s: %s\n\n' % (
 			_('Health issue'),
 			row['health_issue']
 		)
@@ -359,12 +466,12 @@ def search_narrative_in_emr(parent=None, patient=None):
 		style = wx.OK | wx.STAY_ON_TOP
 	)
 	dlg.ShowModal()
-	dlg.Destroy()
+	dlg.DestroyLater()
 
 	return True
 
 #------------------------------------------------------------
-def export_narrative_for_medistar_import(parent=None, soap_cats=u'soapu', encounter=None):
+def export_narrative_for_medistar_import(parent=None, soap_cats='soapu', encounter=None):
 
 	# sanity checks
 	pat = gmPerson.gmCurrentPatient()
@@ -396,11 +503,11 @@ def export_narrative_for_medistar_import(parent=None, soap_cats=u'soapu', encoun
 		defaultDir = aDefDir,
 		defaultFile = fname,
 		wildcard = aWildcard,
-		style = wx.SAVE
+		style = wx.FD_SAVE
 	)
 	choice = dlg.ShowModal()
 	fname = dlg.GetPath()
-	dlg.Destroy()
+	dlg.DestroyLater()
 	if choice != wx.ID_OK:
 		return False
 
@@ -410,7 +517,7 @@ def export_narrative_for_medistar_import(parent=None, soap_cats=u'soapu', encoun
 	successful, fname = exporter.save_to_file (
 		filename = fname,
 		encounter = encounter,
-		soap_cats = u'soapu',
+		soap_cats = 'soapu',
 		export_to_import_file = True
 	)
 	if not successful:
@@ -436,12 +543,12 @@ def select_narrative(parent=None, soap_cats=None, msg=None):
 		parent = wx.GetApp().GetTopWindow()
 
 	if soap_cats is None:
-		soap_cats = u'soapu'
+		soap_cats = 'soapu'
 	soap_cats = list(soap_cats)
 	i18n_soap_cats = [ gmSoapDefs.soap_cat2l10n[cat].upper() for cat in soap_cats ]
 
 	if msg is None:
-		msg = _('Pick the [%s] narrative you want to use.') % u'/'.join(i18n_soap_cats)
+		msg = _('Pick the [%s] narrative you want to use.') % '/'.join(i18n_soap_cats)
 
 	#-----------------------------------------------
 	def get_tooltip(soap):
@@ -463,7 +570,7 @@ def select_narrative(parent=None, soap_cats=None, msg=None):
 	return gmListWidgets.get_choices_from_list (
 		parent = parent,
 		msg = msg,
-		caption = _('Picking [%s] narrative') % (u'/'.join(i18n_soap_cats)),
+		caption = _('Picking [%s] narrative') % ('/'.join(i18n_soap_cats)),
 		columns = [_('When'), _('Who'), _('Type'), _('Entry'), _('Episode'), _('Issue')],
 		single_selection = False,
 		can_return_empty = False,
@@ -487,7 +594,7 @@ def select_narrative_by_issue(parent=None, soap_cats=None):
 		parent = wx.GetApp().GetTopWindow()
 
 	if soap_cats is None:
-		soap_cats = u'soapu'
+		soap_cats = 'soapu'
 	soap_cats = list(soap_cats)
 	i18n_soap_cats = [ gmSoapDefs.soap_cat2l10n[cat].upper() for cat in soap_cats ]
 
@@ -511,9 +618,9 @@ def select_narrative_by_issue(parent=None, soap_cats=None):
 
 		selected_narr = gmListWidgets.get_choices_from_list (
 			parent = parent,
-			msg = _('Pick the [%s] narrative you want to include in the report.') % u'/'.join(i18n_soap_cats),
+			msg = _('Pick the [%s] narrative you want to include in the report.') % '/'.join(i18n_soap_cats),
 			caption = _('Picking [%s] from %s%s%s') % (
-				u'/'.join(i18n_soap_cats),
+				'/'.join(i18n_soap_cats),
 				gmTools.u_left_double_angle_quote,
 				issue['description'],
 				gmTools.u_right_double_angle_quote
@@ -548,7 +655,7 @@ def select_narrative_by_issue(parent=None, soap_cats=None):
 		#issues = [ i for i in emr.health_issues ]
 		issues = emr.health_issues
 		lctrl.set_string_items ([ [
-				gmTools.bool2subst(i['is_confidential'], _('!! CONFIDENTIAL !!'), u''),
+				gmTools.bool2subst(i['is_confidential'], _('!! CONFIDENTIAL !!'), ''),
 				i['description'],
 				gmTools.bool2subst(i['is_active'], _('active'), _('inactive'))
 			] for i in issues
@@ -573,7 +680,7 @@ def select_narrative_by_issue(parent=None, soap_cats=None):
 	issues_picked_from = gmListWidgets.get_choices_from_list (
 		parent = parent,
 		msg = _('\n Select the issue you want to report on.'),
-		caption = _('Picking [%s] from health issues') % u'/'.join(i18n_soap_cats),
+		caption = _('Picking [%s] from health issues') % '/'.join(i18n_soap_cats),
 		columns = [_('Privacy'), _('Issue'), _('Status')],
 		edit_callback = edit_issue,
 		refresh_callback = refresh_issues,
@@ -582,7 +689,7 @@ def select_narrative_by_issue(parent=None, soap_cats=None):
 		ignore_OK_button = False,
 		left_extra_button = (
 			_('&Pick notes'),
-			_('Pick [%s] entries from selected health issue') % u'/'.join(i18n_soap_cats),
+			_('Pick [%s] entries from selected health issue') % '/'.join(i18n_soap_cats),
 			pick_soap_from_issue
 		),
 		list_tooltip_callback = get_issue_tooltip
@@ -606,7 +713,7 @@ def select_narrative_by_episode(parent=None, soap_cats=None):
 	pat = gmPerson.gmCurrentPatient()
 	emr = pat.emr
 
-	all_epis = [ epi for epi in emr.get_episodes(order_by = u'description') if epi.has_narrative ]
+	all_epis = [ epi for epi in emr.get_episodes(order_by = 'description') if epi.has_narrative ]
 	if len(all_epis) == 0:
 		gmDispatcher.send(signal = 'statustext', msg = _('No episodes with progress notes found.'))
 		return []
@@ -615,7 +722,7 @@ def select_narrative_by_episode(parent=None, soap_cats=None):
 		parent = wx.GetApp().GetTopWindow()
 
 	if soap_cats is None:
-		soap_cats = u'soapu'
+		soap_cats = 'soapu'
 	soap_cats = list(soap_cats)
 	i18n_soap_cats = [ gmSoapDefs.soap_cat2l10n[cat].upper() for cat in soap_cats ]
 
@@ -639,9 +746,9 @@ def select_narrative_by_episode(parent=None, soap_cats=None):
 
 		selected_narr = gmListWidgets.get_choices_from_list (
 			parent = parent,
-			msg = _('Pick the [%s] narrative you want to include in the report.') % u'/'.join(i18n_soap_cats),
+			msg = _('Pick the [%s] narrative you want to include in the report.') % '/'.join(i18n_soap_cats),
 			caption = _('Picking [%s] from %s%s%s') % (
-				u'/'.join(i18n_soap_cats),
+				'/'.join(i18n_soap_cats),
 				gmTools.u_left_double_angle_quote,
 				episode['description'],
 				gmTools.u_right_double_angle_quote
@@ -688,9 +795,9 @@ def select_narrative_by_episode(parent=None, soap_cats=None):
 		return gmEMRStructWidgets.edit_episode(parent = parent, episode = episode)
 	#-----------------------------------------------
 	def refresh_episodes(lctrl):
-		all_epis = [ epi for epi in emr.get_episodes(order_by = u'description') if epi.has_narrative ]
+		all_epis = [ epi for epi in emr.get_episodes(order_by = 'description') if epi.has_narrative ]
 		lctrl.set_string_items ([ [
-				u'%s%s' % (e['description'], gmTools.coalesce(e['health_issue'], u'', u' (%s)')),
+				'%s%s' % (e['description'], gmTools.coalesce(e['health_issue'], '', ' (%s)')),
 				gmTools.bool2subst(e['episode_open'], _('open'), _('closed'))
 			] for e in all_epis
 		])
@@ -713,7 +820,7 @@ def select_narrative_by_episode(parent=None, soap_cats=None):
 	epis_picked_from = gmListWidgets.get_choices_from_list (
 		parent = parent,
 		msg = _('\n Select the episode you want to report on.'),
-		caption = _('Picking [%s] from episodes') % u'/'.join(i18n_soap_cats),
+		caption = _('Picking [%s] from episodes') % '/'.join(i18n_soap_cats),
 		columns = [_('Episode'), _('Status')],
 		edit_callback = edit_episode,
 		refresh_callback = refresh_episodes,
@@ -722,7 +829,7 @@ def select_narrative_by_episode(parent=None, soap_cats=None):
 		ignore_OK_button = False,
 		left_extra_button = (
 			_('&Pick notes'),
-			_('Pick [%s] entries from selected episode') % u'/'.join(i18n_soap_cats),
+			_('Pick [%s] entries from selected episode') % '/'.join(i18n_soap_cats),
 			pick_soap_from_episode
 		),
 		list_tooltip_callback = get_episode_tooltip
@@ -773,7 +880,7 @@ def select_narrative_from_episodes(parent=None, soap_cats=None):
 			dlg.set_selections(selections = selection_idxs)
 		btn_pressed = dlg.ShowModal()
 		selected_issues = dlg.get_selected_item_data()
-		dlg.Destroy()
+		dlg.DestroyLater()
 
 		if btn_pressed == wx.ID_CANCEL:
 			return selected_soap.values()
@@ -805,7 +912,7 @@ def select_narrative_from_episodes(parent=None, soap_cats=None):
 				dlg.set_selections(selections = selection_idxs)
 			btn_pressed = dlg.ShowModal()
 			selected_epis = dlg.get_selected_item_data()
-			dlg.Destroy()
+			dlg.DestroyLater()
 
 			if btn_pressed == wx.ID_CANCEL:
 				break
@@ -826,7 +933,7 @@ def select_narrative_from_episodes(parent=None, soap_cats=None):
 				msg = _(
 					'\n This is the narrative (type %s) for the chosen episodes.\n\n'
 					' Now, mark the entries you want to include in your report.\n'
-				) % u'/'.join([ gmSoapDefs.soap_cat2l10n[cat] for cat in gmTools.coalesce(soap_cats, list(u'soapu')) ])
+				) % '/'.join([ gmSoapDefs.soap_cat2l10n[cat] for cat in gmTools.coalesce(soap_cats, list('soapu')) ])
 			)
 			selection_idxs = []
 			for idx in range(len(all_narr)):
@@ -836,7 +943,7 @@ def select_narrative_from_episodes(parent=None, soap_cats=None):
 				dlg.set_selections(selections = selection_idxs)
 			btn_pressed = dlg.ShowModal()
 			selected_narr = dlg.get_selected_item_data()
-			dlg.Destroy()
+			dlg.DestroyLater()
 
 			if btn_pressed == wx.ID_CANCEL:
 				continue
@@ -867,18 +974,18 @@ if __name__ == '__main__':
 		set_active_patient(patient = pat)
 		app = wx.PyWidgetTester(size = (200, 200))
 		sels = select_narrative_from_episodes_new()
-		print "selected:"
+		print("selected:")
 		for sel in sels:
-			print sel
+			print(sel)
 	#----------------------------------------
 	def test_select_narrative():
 		pat = gmPersonSearch.ask_for_patient()
 		set_active_patient(patient = pat)
 		app = wx.PyWidgetTester(size = (200, 200))
 		sels = select_narrative(parent=None, soap_cats = None)
-		print "selected:"
+		print("selected:")
 		for sel in sels:
-			print sel
+			print(sel)
 	#----------------------------------------
 	#test_select_narrative_from_episodes()
 	test_select_narrative()
